|PyPI Version| |Python Version|

A command-line tool and Python library to convert, validate and explore `Open Fibre Data Standard <https://open-fibre-data-standard.readthedocs.io>`__ (OFDS) data:

- Validate data against the schema
- Check that data conforms to normative rules specified in OFDS
- Report additional fields not specified in the schema
- Convert data from JSON format to GeoJSON format
- Convert data from GeoJSON to JSON format

If you are viewing this on GitHub or PyPI, open the `full documentation <https://libcoveofds.readthedocs.io>`__ for additional details.

.. |PyPI Version| image:: https://img.shields.io/pypi/v/libcoveofds.svg
   :target: https://pypi.org/project/libcoveofds
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/libcoveofds.svg
   :target: https://pypi.org/project/libcoveofds/
